==> org-lsst-ccs-subsystem-fcs-buses-5.5.12-sources.jar: org/lsst/ccs/subsystems/fcs/StatusDataPublishedByAutoChanger.java <==
package org.lsst.ccs.subsystems.fcs;

import java.io.Serializable;
import org.lsst.ccs.bus.annotations.DataAttributes;

/**
 *
 * A structure for the data published on the status bus by the
 * class Autochanger.
 *
 * @author virieux
 *
 */
public class StatusDataPublishedByAutoChanger implements Serializable {

    private static final long serialVersionUID = 1L;
    
    //Loader_LPS Loader is connected and at Storage position
    private boolean loaderConnectedSensorValue;
    private boolean loaderConnectedSensorsInError;
    
    //Loader_LRH Loader is holding filter at HANDOFF
    private boolean loader_LRH; 
    private boolean loader_LRH_InError;

    //Carousel signals
    private boolean carouselHoldingFilter;
    private boolean carousel_CS;
    private boolean carousel_CF0;
    private boolean carousel_CF1;
    private boolean carouselHoldingFilterInError;
    private boolean carousel_CS_InError;
    private boolean carousel_CF0_InError;
    private boolean carousel_CF1_InError;

    //Signals emitted by autochanger
    private boolean OUT_AF0;
    private boolean OUT_AF1;
    private boolean OUT_AF3;
    private boolean OUT_AP1;
    private boolean OUT_AP2;
    private boolean OUT_AP3;
    private boolean OUT_AF0_InError;
    private boolean OUT_AF1_InError;
    private boolean OUT_AF3_InError;
    private boolean OUT_AP1_InError;
    private boolean OUT_AP2_InError;
    private boolean OUT_AP3_InError;
    
    //Local Protection Module signals;
    private boolean enableRailLin1;
    private boolean enableRailLin2;
    private boolean enableClamps;
    private boolean enableLatches;
    private boolean engineeringKey;
    private boolean engineeringKey_InError;

    //Sensors on AC1 and AC2, not on PROTO
    private boolean loaderPresence;
    private boolean loaderPresenceInError;
    private boolean lockOut;
    private boolean lockOutInError;
    
    //Inclinometers
    @DataAttributes(description = "inclinaison returned by inclinometerXminus", units = "degree")
    private double inclinaisonXminus;

    @DataAttributes(description = "inclinaison returned by inclinometerXplus", units = "degree")
    private double inclinaisonXplus;

    public boolean getLoaderConnectedSensorValue() {
        return loaderConnectedSensorValue;
    }

    public void setLoaderConnectedSensorValue(boolean loaderConnectedSensorValue0) {
        this.loaderConnectedSensorValue = loaderConnectedSensorValue0;
    }

    public boolean isLoaderConnectedSensorsInError() {
        return loaderConnectedSensorsInError;
    }

    public void setLoaderConnectedSensorsInError(boolean loaderConnectedSensorsInError) {
        this.loaderConnectedSensorsInError = loaderConnectedSensorsInError;
    }

    public boolean isCarouselHoldingFilter() {
        return carouselHoldingFilter;
    }

    public void setCarouselHoldingFilter(boolean carouselHoldingFilter) {
        this.carouselHoldingFilter = carouselHoldingFilter;
    }

    public boolean isCarousel_CS() {
        return carousel_CS;
    }

    public void setCarousel_CS(boolean carousel_CS) {
        this.carousel_CS = carousel_CS;
    }

    public boolean isCarousel_CF0() {
        return carousel_CF0;
    }

    public void setCarousel_CF0(boolean carousel_CF0) {
        this.carousel_CF0 = carousel_CF0;
    }

    public boolean isCarousel_CF1() {
        return carousel_CF1;
    }

    public void setCarousel_CF1(boolean carousel_CF1) {
        this.carousel_CF1 = carousel_CF1;
    }

    public boolean isCarouselHoldingFilterInError() {
        return carouselHoldingFilterInError;
    }

    public void setCarouselHoldingFilterInError(boolean carouselHoldingFilterInError) {
        this.carouselHoldingFilterInError = carouselHoldingFilterInError;
    }

    public boolean isCarousel_CS_InError() {
        return carousel_CS_InError;
    }

    public void setCarousel_CS_InError(boolean carousel_CS_InError) {
        this.carousel_CS_InError = carousel_CS_InError;
    }

    public boolean isCarousel_CF0_InError() {
        return carousel_CF0_InError;
    }

    public void setCarousel_CF0_InError(boolean carousel_CF0_InError) {
        this.carousel_CF0_InError = carousel_CF0_InError;
    }

    public boolean isCarousel_CF1_InError() {
        return carousel_CF1_InError;
    }

    public void setCarousel_CF1_InError(boolean carousel_CF1_InError) {
        this.carousel_CF1_InError = carousel_CF1_InError;
    }

    public boolean isLoaderPresence() {
        return loaderPresence;
    }

    public void setLoaderPresence(boolean loaderPresence) {
        this.loaderPresence = loaderPresence;
    }

    public boolean isLoaderPresenceInError() {
        return loaderPresenceInError;
    }

    public void setLoaderPresenceInError(boolean loaderPresenceInError) {
        this.loaderPresenceInError = loaderPresenceInError;
    }

    public boolean isLockOut() {
        return lockOut;
    }

    public void setLockOut(boolean lockOut) {
        this.lockOut = lockOut;
    }

    public boolean isLockOutInError() {
        return lockOutInError;
    }

    public void setLockOutInError(boolean lockOutInError) {
        this.lockOutInError = lockOutInError;
    }
    
    public double getInclinaisonXminus() {
        return inclinaisonXminus;
    }

    public void setInclinaisonXminus(double inclinaisonXminus) {
        this.inclinaisonXminus = inclinaisonXminus;
    }

    public double getInclinaisonXplus() {
        return inclinaisonXplus;
    }

    public void setInclinaisonXplus(double inclinaisonXplus) {
        this.inclinaisonXplus = inclinaisonXplus;
    }

    public boolean isLoaderHoldingFilterAtHandoff() {
        return loader_LRH;
    }

    public void setLoaderHoldingFilterAtHandoff(boolean loaderHoldingFilterAtHandoff) {
        this.loader_LRH = loaderHoldingFilterAtHandoff;
    }

    public boolean isLoaderHoldingFilterAtHandoffInError() {
        return loader_LRH_InError;
    }

    public void setLoaderHoldingFilterAtHandoffInError(boolean loaderHoldingFilterAtHandoffInError) {
        this.loader_LRH_InError = loaderHoldingFilterAtHandoffInError;
    }

    public boolean isEnableRailLin1() {
        return enableRailLin1;
    }

    public void setEnableRailLin1(boolean enableRailLin1) {
        this.enableRailLin1 = enableRailLin1;
    }

    public boolean isEnableRailLin2() {
        return enableRailLin2;
    }

    public void setEnableRailLin2(boolean enableRailLin2) {
        this.enableRailLin2 = enableRailLin2;
    }

    public boolean isEnableClamps() {
        return enableClamps;
    }

    public void setEnableClamps(boolean enableClamps) {
        this.enableClamps = enableClamps;
    }

    public boolean isEnableLatches() {
        return enableLatches;
    }

    public void setEnableLatches(boolean enableLatches) {
        this.enableLatches = enableLatches;
    }

    public boolean isEngineeringKey() {
        return engineeringKey;
    }

    public void setEngineeringKey(boolean engineeringKey) {
        this.engineeringKey = engineeringKey;
    }

    public boolean isEngineeringKey_InError() {
        return engineeringKey_InError;
    }

    public void setEngineeringKey_InError(boolean engineeringKey_InError) {
        this.engineeringKey_InError = engineeringKey_InError;
    }

    public boolean isOUT_AF0() {
        return OUT_AF0;
    }

    public void setOUT_AF0(boolean OUT_AF0) {
        this.OUT_AF0 = OUT_AF0;
    }

    public boolean isOUT_AF1() {
        return OUT_AF1;
    }

    public void setOUT_AF1(boolean OUT_AF1) {
        this.OUT_AF1 = OUT_AF1;
    }

    public boolean isOUT_AF3() {
        return OUT_AF3;
    }

    public void setOUT_AF3(boolean OUT_AF3) {
        this.OUT_AF3 = OUT_AF3;
    }

    public boolean isOUT_AP1() {
        return OUT_AP1;
    }

    public void setOUT_AP1(boolean OUT_AP1) {
        this.OUT_AP1 = OUT_AP1;
    }

    public boolean isOUT_AP2() {
        return OUT_AP2;
    }

    public void setOUT_AP2(boolean OUT_AP2) {
        this.OUT_AP2 = OUT_AP2;
    }

    public boolean isOUT_AP3() {
        return OUT_AP3;
    }

    public void setOUT_AP3(boolean OUT_AP3) {
        this.OUT_AP3 = OUT_AP3;
    }

    public boolean isOUT_AF0_InError() {
        return OUT_AF0_InError;
    }

    public void setOUT_AF0_InError(boolean OUT_AF0_InError) {
        this.OUT_AF0_InError = OUT_AF0_InError;
    }

    public boolean isOUT_AF1_InError() {
        return OUT_AF1_InError;
    }

    public void setOUT_AF1_InError(boolean OUT_AF1_InError) {
        this.OUT_AF1_InError = OUT_AF1_InError;
    }

    public boolean isOUT_AF3_InError() {
        return OUT_AF3_InError;
    }

    public void setOUT_AF3_InError(boolean OUT_AF3_InError) {
        this.OUT_AF3_InError = OUT_AF3_InError;
    }

    public boolean isOUT_AP1_InError() {
        return OUT_AP1_InError;
    }

    public void setOUT_AP1_InError(boolean OUT_AP1_InError) {
        this.OUT_AP1_InError = OUT_AP1_InError;
    }

    public boolean isOUT_AP2_InError() {
        return OUT_AP2_InError;
    }

    public void setOUT_AP2_InError(boolean OUT_AP2_InError) {
        this.OUT_AP2_InError = OUT_AP2_InError;
    }

    public boolean isOUT_AP3_InError() {
        return OUT_AP3_InError;
    }

    public void setOUT_AP3_InError(boolean OUT_AP3_InError) {
        this.OUT_AP3_InError = OUT_AP3_InError;
    }

}

==> org-lsst-ccs-subsystem-fcs-buses-6.1.0-sources.jar: org/lsst/ccs/subsystems/fcs/StatusDataPublishedByAutoChanger.java <==
package org.lsst.ccs.subsystems.fcs;

import java.io.Serializable;
import org.lsst.ccs.bus.annotations.DataAttributes;

/**
 *
 * A structure for the data published on the status bus by the
 * class Autochanger.
 *
 * @author virieux
 *
 */
public class StatusDataPublishedByAutoChanger implements Serializable {

    private static final long serialVersionUID = 1L;
    
    //Loader_LPS Loader is connected and at Storage position
    private boolean loaderConnectedSensorValue;
    private boolean loaderConnectedSensorsInError;
    
    //Loader_LRH Loader is holding filter at HANDOFF
    private boolean loader_LRH; 
    private boolean loader_LRH_InError;

    //Carousel signals
    private boolean carouselHoldingFilter;
    private boolean carousel_CS;
    private boolean carousel_CF0;
    private boolean carousel_CF1;
    private boolean carouselHoldingFilterInError;
    private boolean carousel_CS_InError;
    private boolean carousel_CF0_InError;
    private boolean carousel_CF1_InError;

    //Signals emitted by autochanger
    private boolean OUT_AF0;
    private boolean OUT_AF1;
    private boolean OUT_AF3;
    private boolean OUT_AP1;
    private boolean OUT_AP2;
    private boolean OUT_AP3;
    private boolean OUT_AIN;
    private boolean OUT_AOL;
    private boolean OUT_AF0_InError;
    private boolean OUT_AF1_InError;
    private boolean OUT_AF3_InError;
    private boolean OUT_AP1_InError;
    private boolean OUT_AP2_InError;
    private boolean OUT_AP3_InError;

    //Local Protection Module signals;
    private boolean enableRailLin1;
    private boolean enableRailLin2;
    private boolean enableClamps;
    private boolean enableLatches;
    private boolean engineeringKey;
    private boolean engineeringKey_InError;

    //Sensors on AC1 and AC2, not on PROTO
    private boolean loaderPresence;
    private boolean loaderPresenceInError;
    private boolean lockOut;
    private boolean lockOutInError;
    private boolean lockOutShunt;

    //Inclinometers
    @DataAttributes(description = "inclinaison returned by inclinometerXminus", units = "degree")
    private double inclinaisonXminus;

    @DataAttributes(description = "inclinaison returned by inclinometerXplus", units = "degree")
    private double inclinaisonXplus;

    public boolean getLoaderConnectedSensorValue() {
        return loaderConnectedSensorValue;
    }

    public void setLoaderConnectedSensorValue(boolean loaderConnectedSensorValue0) {
        this.loaderConnectedSensorValue = loaderConnectedSensorValue0;
    }

    public boolean isLoaderConnectedSensorsInError() {
        return loaderConnectedSensorsInError;
    }

    public void setLoaderConnectedSensorsInError(boolean loaderConnectedSensorsInError) {
        this.loaderConnectedSensorsInError = loaderConnectedSensorsInError;
    }

    public boolean isCarouselHoldingFilter() {
        return carouselHoldingFilter;
    }

    public void setCarouselHoldingFilter(boolean carouselHoldingFilter) {
        this.carouselHoldingFilter = carouselHoldingFilter;
    }

    public boolean isCarousel_CS() {
        return carousel_CS;
    }

    public void setCarousel_CS(boolean carousel_CS) {
        this.carousel_CS = carousel_CS;
    }

    public boolean isCarousel_CF0() {
        return carousel_CF0;
    }

    public void setCarousel_CF0(boolean carousel_CF0) {
        this.carousel_CF0 = carousel_CF0;
    }

    public boolean isCarousel_CF1() {
        return carousel_CF1;
    }

    public void setCarousel_CF1(boolean carousel_CF1) {
        this.carousel_CF1 = carousel_CF1;
    }

    public boolean isCarouselHoldingFilterInError() {
        return carouselHoldingFilterInError;
    }

    public void setCarouselHoldingFilterInError(boolean carouselHoldingFilterInError) {
        this.carouselHoldingFilterInError = carouselHoldingFilterInError;
    }

    public boolean isCarousel_CS_InError() {
        return carousel_CS_InError;
    }

    public void setCarousel_CS_InError(boolean carousel_CS_InError) {
        this.carousel_CS_InError = carousel_CS_InError;
    }

    public boolean isCarousel_CF0_InError() {
        return carousel_CF0_InError;
    }

    public void setCarousel_CF0_InError(boolean carousel_CF0_InError) {
        this.carousel_CF0_InError = carousel_CF0_InError;
    }

    public boolean isCarousel_CF1_InError() {
        return carousel_CF1_InError;
    }

    public void setCarousel_CF1_InError(boolean carousel_CF1_InError) {
        this.carousel_CF1_InError = carousel_CF1_InError;
    }

    public boolean isLoaderPresence() {
        return loaderPresence;
    }

    public void setLoaderPresence(boolean loaderPresence) {
        this.loaderPresence = loaderPresence;
    }

    public boolean isLoaderPresenceInError() {
        return loaderPresenceInError;
    }

    public void setLoaderPresenceInError(boolean loaderPresenceInError) {
        this.loaderPresenceInError = loaderPresenceInError;
    }

    public boolean isLockOut() {
        return lockOut;
    }

    public void setLockOut(boolean lockOut) {
        this.lockOut = lockOut;
    }

    public boolean isLockOutInError() {
        return lockOutInError;
    }

    public void setLockOutInError(boolean lockOutInError) {
        this.lockOutInError = lockOutInError;
    }
    
    public double getInclinaisonXminus() {
        return inclinaisonXminus;
    }

    public void setInclinaisonXminus(double inclinaisonXminus) {
        this.inclinaisonXminus = inclinaisonXminus;
    }

    public double getInclinaisonXplus() {
        return inclinaisonXplus;
    }

    public void setInclinaisonXplus(double inclinaisonXplus) {
        this.inclinaisonXplus = inclinaisonXplus;
    }

    public boolean isLoaderHoldingFilterAtHandoff() {
        return loader_LRH;
    }

    public void setLoaderHoldingFilterAtHandoff(boolean loaderHoldingFilterAtHandoff) {
        this.loader_LRH = loaderHoldingFilterAtHandoff;
    }

    public boolean isLoaderHoldingFilterAtHandoffInError() {
        return loader_LRH_InError;
    }

    public void setLoaderHoldingFilterAtHandoffInError(boolean loaderHoldingFilterAtHandoffInError) {
        this.loader_LRH_InError = loaderHoldingFilterAtHandoffInError;
    }

    public boolean isEnableRailLin1() {
        return enableRailLin1;
    }

    public void setEnableRailLin1(boolean enableRailLin1) {
        this.enableRailLin1 = enableRailLin1;
    }

    public boolean isEnableRailLin2() {
        return enableRailLin2;
    }

    public void setEnableRailLin2(boolean enableRailLin2) {
        this.enableRailLin2 = enableRailLin2;
    }

    public boolean isEnableClamps() {
        return enableClamps;
    }

    public void setEnableClamps(boolean enableClamps) {
        this.enableClamps = enableClamps;
    }

    public boolean isEnableLatches() {
        return enableLatches;
    }

    public void setEnableLatches(boolean enableLatches) {
        this.enableLatches = enableLatches;
    }

    public boolean isEngineeringKey() {
        return engineeringKey;
    }

    public void setEngineeringKey(boolean engineeringKey) {
        this.engineeringKey = engineeringKey;
    }

    public boolean isEngineeringKey_InError() {
        return engineeringKey_InError;
    }

    public void setEngineeringKey_InError(boolean engineeringKey_InError) {
        this.engineeringKey_InError = engineeringKey_InError;
    }

    public boolean isOUT_AF0() {
        return OUT_AF0;
    }

    public void setOUT_AF0(boolean OUT_AF0) {
        this.OUT_AF0 = OUT_AF0;
    }

    public boolean isOUT_AF1() {
        return OUT_AF1;
    }

    public void setOUT_AF1(boolean OUT_AF1) {
        this.OUT_AF1 = OUT_AF1;
    }

    public boolean isOUT_AF3() {
        return OUT_AF3;
    }

    public void setOUT_AF3(boolean OUT_AF3) {
        this.OUT_AF3 = OUT_AF3;
    }

    public boolean isOUT_AP1() {
        return OUT_AP1;
    }

    public void setOUT_AP1(boolean OUT_AP1) {
        this.OUT_AP1 = OUT_AP1;
    }

    public boolean isOUT_AP2() {
        return OUT_AP2;
    }

    public void setOUT_AP2(boolean OUT_AP2) {
        this.OUT_AP2 = OUT_AP2;
    }

    public boolean isOUT_AP3() {
        return OUT_AP3;
    }

    public void setOUT_AP3(boolean OUT_AP3) {
        this.OUT_AP3 = OUT_AP3;
    }

    public boolean isOUT_AF0_InError() {
        return OUT_AF0_InError;
    }

    public void setOUT_AF0_InError(boolean OUT_AF0_InError) {
        this.OUT_AF0_InError = OUT_AF0_InError;
    }

    public boolean isOUT_AF1_InError() {
        return OUT_AF1_InError;
    }

    public void setOUT_AF1_InError(boolean OUT_AF1_InError) {
        this.OUT_AF1_InError = OUT_AF1_InError;
    }

    public boolean isOUT_AF3_InError() {
        return OUT_AF3_InError;
    }

    public void setOUT_AF3_InError(boolean OUT_AF3_InError) {
        this.OUT_AF3_InError = OUT_AF3_InError;
    }

    public boolean isOUT_AP1_InError() {
        return OUT_AP1_InError;
    }

    public void setOUT_AP1_InError(boolean OUT_AP1_InError) {
        this.OUT_AP1_InError = OUT_AP1_InError;
    }

    public boolean isOUT_AP2_InError() {
        return OUT_AP2_InError;
    }

    public void setOUT_AP2_InError(boolean OUT_AP2_InError) {
        this.OUT_AP2_InError = OUT_AP2_InError;
    }

    public boolean isOUT_AP3_InError() {
        return OUT_AP3_InError;
    }

    public void setOUT_AP3_InError(boolean OUT_AP3_InError) {
        this.OUT_AP3_InError = OUT_AP3_InError;
    }

    public boolean isLoader_LRH() {
        return loader_LRH;
    }

    public void setLoader_LRH(boolean loader_LRH) {
        this.loader_LRH = loader_LRH;
    }

    public boolean isLoader_LRH_InError() {
        return loader_LRH_InError;
    }

    public void setLoader_LRH_InError(boolean loader_LRH_InError) {
        this.loader_LRH_InError = loader_LRH_InError;
    }

    public boolean isOUT_AIN() {
        return OUT_AIN;
    }

    public void setOUT_AIN(boolean AIN) {
        this.OUT_AIN = AIN;
    }

    public boolean isOUT_AOL() {
        return OUT_AOL;
    }

    public void setOUT_AOL(boolean AOL) {
        this.OUT_AOL = AOL;
    }

    public boolean isLockOutShunt() {
        return lockOutShunt;
    }

    public void setLockOutShunt(boolean lockOutShunt) {
        this.lockOutShunt = lockOutShunt;
    }

}
